@@ -1,25 +1,26 @@
 """
 This module contains a generic patch method that wraps a function with a span.
 """
+
 from langtrace.trace_attributes import FrameworkSpanAttributes
 from opentelemetry.trace import SpanKind
 from opentelemetry.trace.status import Status, StatusCode
 
-from langtrace_python_sdk.constants.instrumentation.common import \
-    SERVICE_PROVIDERS
+from langtrace_python_sdk.constants.instrumentation.common import SERVICE_PROVIDERS
 
 
 def generic_patch(method, task, tracer, version):
     """
     A generic patch method that wraps a function with a span"""
+
     def traced_method(wrapped, instance, args, kwargs):
-        service_provider = SERVICE_PROVIDERS['LLAMAINDEX']
+        service_provider = SERVICE_PROVIDERS["LLAMAINDEX"]
         span_attributes = {
-            'langtrace.service.name': service_provider,
-            'langtrace.service.type': 'framework',
-            'langtrace.service.version': version,
-            'langtrace.version': '1.0.0',
-            'llamaindex.task.name': task,
+            "langtrace.service.name": service_provider,
+            "langtrace.service.type": "framework",
+            "langtrace.service.version": version,
+            "langtrace.version": "1.0.0",
+            "llamaindex.task.name": task,
         }
 
         attributes = FrameworkSpanAttributes(**span_attributes)
